# 🌐 Hurricane-Idalia-2023

paused ⏸️ - [dev notes](https://arash-kamangir.medium.com/%EF%B8%8F-conversations-with-ai-229-9257441b3ac0), [dev notes](https://medium.com/@arash-kamangir/%EF%B8%8F-conversations-with-ai-228-f55a0fdf409a).

 - [Google Maps](https://maps.app.goo.gl/CAeoKQrZQ9rTsDrGA): `lat: 29.0000"N`, `lon: 83.0000"W`.
 - [National Weather Service](https://www.weather.gov/tae/HurricaneIdalia2023): Hurricane Idalia Strikes the Florida Big Bend.
 - [Wikipedia](https://en.wikipedia.org/wiki/Hurricane_Idalia): A powerful and destructive Category 4 hurricane that caused significant damage across parts of the southeastern, in late August 2023.

---

used by: [`@geo watch`](../../).
